
This attribute is to match :attr:`importlib.machinery.ModuleSpec.parent`
as stored in the :attr:`__spec__` object.

the same format as the :c:macro:`PY_VERSION_HEX` macro.

(Contributed by Omar Sandoval, :issue:`26273`).
